package com.dgtly.sync.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.dgtly.common.exception.BusinessException;
import com.dgtly.common.utils.ShiroSaltUtil;
import com.dgtly.common.utils.security.EncryptPassWordClass;
import com.dgtly.sync.domain.MetaEmployeeDiy;
import com.dgtly.sync.domain.SyncFailDetail;
import com.dgtly.sync.domain.SyncLog;
import com.dgtly.sync.exception.NotFountOrgCodeException;
import com.dgtly.sync.exception.OutOfScopeDIYException;
import com.dgtly.sync.mapper.MetaDiySalesorgtreeMapper;
import com.dgtly.sync.mapper.MetaEmployeeDiyMapper;
import com.dgtly.sync.mapper.SyncFailDetailMapper;
import com.dgtly.sync.service.IAnalysisSysUserService;
import com.dgtly.sync.service.ISyncLogService;
import com.dgtly.system.domain.SysDictData;
import com.dgtly.system.domain.SysUser;
import com.dgtly.system.domain.SysUserSalesExt;
import com.dgtly.system.service.ISysConfigService;
import com.dgtly.system.service.ISysDictDataService;
import com.dgtly.system.service.ISysUserService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import java.util.*;

@Service
public class AnalysisSysUserService implements IAnalysisSysUserService {

    private static final Logger log = LoggerFactory.getLogger(AnalysisSysUserService.class);




    @Autowired
    private SyncFailDetailMapper syncFailDetailMapper;
    @Autowired
    private ISysConfigService configService;
    @Autowired
    private ISysDictDataService sysDictDataService;

    @Autowired
    private ISysUserService sysUserService;
    @Autowired
    private MetaEmployeeDiyMapper metaEmployeeDiyMapper;
    @Autowired
    private MetaDiySalesorgtreeMapper metaDiySalesorgtreeMapper;
    @Autowired
    private ISyncLogService syncLogService;



    /**
     * 解析部门数据  异步执行
     * @param packageId
     * @return
     */
    @Override
    @Async
    public SyncLog analysisSysUser(String packageId){
        MetaEmployeeDiy param = new MetaEmployeeDiy();
        param.setPackageId(packageId);

        SyncLog syncLog = new SyncLog();
        syncLog.setSyncType("sysuser");
        syncLog.setStartTime(new Date());

        Set<String> loginNameList = sysUserService.selectAllUserLoginName();
        List<MetaEmployeeDiy> metaEmployeeDiys = metaEmployeeDiyMapper.selectMetaEmployeeDiyList(param);

        syncLog.setPackageId(packageId);
        syncLog.setTotalCount((long)metaEmployeeDiys.size());
        List<SyncFailDetail> failDetails = new ArrayList<>();
        long successCount = 0;
        long failCount = 0;

        Long deptId = Long.parseLong(configService.selectConfigByKey("libang.user.deptid"));
        Long roleId = Long.parseLong(configService.selectConfigByKey("libang.user.roleid"));
        Long[] roleIds = {roleId};
        if(metaEmployeeDiys.size()>0){

            //用户objid3为列表内的内容才为DIY人员
            Set<String> divObjid3Set =  getConfigValueSet("libang_diyobjid3");
            //用户岗位名称为列表的内容才是区公司级别人员
            Set<String> companySet =  getConfigValueSet("libang_company_level_postname");
            //用户岗位名称为列表的内容才是销售大区级别人员
            Set<String> saledeptSet =  getConfigValueSet("libang_saledept_level_postname");
            //用户岗位名称为列表的内容才是销售部级别人员
            Set<String> officeSet =  getConfigValueSet("libang_office_level_postname");
            //用户岗位名称为列表的内容才是销售分部级别人员
            Set<String> subofficeSet =  getConfigValueSet("libang_suboffice_level_postname");
            //用户岗位名称为列表的内容才是销售员级别人员
            Set<String> empSet =  getConfigValueSet("libang_emp_level_postname");




            for(MetaEmployeeDiy m:metaEmployeeDiys) {
                try {
                    if(!divObjid3Set.contains(m.getStext3())){
                        throw new OutOfScopeDIYException(m);
                    }
                    /**
                     * 用户基本信息构建
                     */
                    SysUser user = new SysUser();
                    user.setCompanyId(1L);
                    user.setDeptId(deptId);
                    user.setLoginName(m.getLoginName());
                    user.setUserName(m.getName());
                    user.setEmail(m.getEmail());
                    user.setPhonenumber(m.getMobile());
                    String sex = ""+(Integer.parseInt(m.getSex())-1);
                    user.setSex(sex);
                    user.setRoleIds(roleIds);
                    SysUserSalesExt userSalesExt = new SysUserSalesExt();
                    userSalesExt.setBossEmployeeId(m.getBossEmployeeId());
                    userSalesExt.setBossName(m.getBossName());
                    userSalesExt.setSapEmployeeId(m.getSapEmployeeId());

                    if (m.getStatus() == 0) {
                        user.setStatus("1");
                        user.setDelFlag("2");
                    } else {
                        user.setStatus("0");
                    }



                    if (loginNameList.contains(user.getLoginName())) {
                        user.setSysUserSalesExt(userSalesExt);
                        sysUserService.updateUserInfoAndSalesExt(user);
                    } else {

                        /**
                         * 用判断用户所处销售层级
                         */
                        String fildName ="";
                        String fildCode = "";
                        if(m.getStext6()!=null){
                            if(empSet.contains(m.getEmployeePostName())){
                                userSalesExt.setSalesLevel("emp_level");
                                userSalesExt.setOrgName(m.getStext6());
                                fildName = "Org6name";
                                fildCode = "Org6code";
                            }else if(subofficeSet.contains(m.getEmployeePostName())){
                                userSalesExt.setSalesLevel("suboffice_level");
                                userSalesExt.setOrgName(m.getStext6());
                                fildName = "Org6name";
                                fildCode = "Org6code";
                            }else{
                                throw new OutOfScopeDIYException(m);
                            }
                        }else if(m.getStext5()!=null){
                            if(officeSet.contains(m.getEmployeePostName())){
                                userSalesExt.setSalesLevel("suboffice_level");
                                userSalesExt.setOrgName(m.getStext5());
                                fildName = "Org5name";
                                fildCode = "Org5code";
                            }else{
                                throw new OutOfScopeDIYException(m);
                            }
                        }else if(m.getStext4()!=null){
                            if(saledeptSet.contains(m.getEmployeePostName())){
                                userSalesExt.setSalesLevel("office_level");
                                userSalesExt.setOrgName(m.getStext4());
                                fildName = "Org4name";
                                fildCode = "Org4code";
                            } else{
                                throw new OutOfScopeDIYException(m);
                            }
                        }else if(m.getStext3()!=null){
                            if(companySet.contains(m.getEmployeePostName())){
                                userSalesExt.setSalesLevel("office_level");
                                userSalesExt.setOrgName(m.getStext3());
                                fildName = "Org3name";
                                fildCode = "Org3code";
                            } else{
                                throw new OutOfScopeDIYException(m);
                            }
                        }else{
                            throw new OutOfScopeDIYException(m);
                        }



                        if(userSalesExt.getOrgName()!=null){
                            Map<String,String> map=  metaDiySalesorgtreeMapper.selectSalesorgByName(fildName,fildCode,userSalesExt.getOrgName());
                            if(map!=null && map.containsKey("orgcode")){
                                userSalesExt.setOrgCode(map.get("orgcode"));
                            }
                        }
                        if(userSalesExt.getOrgCode()==null){
                            throw new NotFountOrgCodeException(m);
                        }
                        //修改密码并加密
                        user.setPassword(m.getLoginName());
                        user.setSalt(ShiroSaltUtil.randomSalt());
                        user.setPassword(EncryptPassWordClass.encryptPassword(user.getLoginName(), user.getPassword(), user.getSalt()));
                        user.setSysUserSalesExt(userSalesExt);
                        sysUserService.insertUserAndSalesExt(user);
                        successCount++;

                    }

                }catch (OutOfScopeDIYException|NotFountOrgCodeException e){
                    /**
                     * 警告类异常
                     */
                    SyncFailDetail syncFailDetail = new SyncFailDetail();
                    syncFailDetail.setPackageId(packageId);
                    syncFailDetail.setFailReason(e.getMessage());
                    syncFailDetail.setDataJson(JSONObject.toJSONString(m));
                    syncFailDetail.setFailLevel("0");
                    syncFailDetail.setExceptionType(e.getClass().getSimpleName());
                    failDetails.add(syncFailDetail);
                    failCount++;
                }catch (Exception e) {
                    /**
                     * 错误异常
                     */
                    SyncFailDetail syncFailDetail = new SyncFailDetail();
                    syncFailDetail.setPackageId(packageId);
                    syncFailDetail.setFailReason(e.getMessage());
                    syncFailDetail.setDataJson(JSONObject.toJSONString(m));
                    syncFailDetail.setFailLevel("1");
                    syncFailDetail.setExceptionType(e.getClass().getSimpleName());
                    failDetails.add(syncFailDetail);
                    e.printStackTrace();
                    log.error("解析用户出错", e);
                    failCount++;
                }
            }
            syncLog.setSuccessCount(successCount);
            syncLog.setFaileCount(failCount);
        }else{
            syncLog.setSuccessCount(0l);
            syncLog.setFaileCount(0l);
        }
        try{
            syncLog.setEndTime(new Date());
            if(failDetails.size()>0){
                syncFailDetailMapper.batchInsertSyncFailDetail(failDetails);
            }
        }catch (Exception e){
            log.error("解析用户插入解析日志出错",e);
            e.printStackTrace();
            throw new BusinessException("解析用户插入解析日志出错",e);
        }finally {
            syncLogService.insertSyncLog(syncLog);
        }
        return syncLog;

    }

    public Set<String> getConfigValueSet(String dictType){
        Set<String> res = new HashSet<>();
        List<SysDictData> dictDatas = sysDictDataService.selectSimpleDictDataByType(dictType);
        for(SysDictData d: dictDatas){
            res.add(d.getDictValue());
        }
        return res;
    }




}
