package com.dgtly.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.dgtly.system.mapper.SysUserSalesExtMapper;
import com.dgtly.system.domain.SysUserSalesExt;
import com.dgtly.system.service.ISysUserSalesExtService;
import com.dgtly.common.core.text.Convert;

/**
 * 用户销售信息扩展Service业务层处理
 * 
 * @author qxp
 * @date 2020-07-29
 */
@Service
public class SysUserSalesExtServiceImpl implements ISysUserSalesExtService 
{
    @Autowired
    private SysUserSalesExtMapper sysUserSalesExtMapper;

    /**
     * 查询用户销售信息扩展
     * 
     * @param userId 用户销售信息扩展ID
     * @return 用户销售信息扩展
     */
    @Override
    public SysUserSalesExt selectSysUserSalesExtById(Long userId)
    {
        return sysUserSalesExtMapper.selectSysUserSalesExtById(userId);
    }

    /**
     * 查询用户销售信息扩展列表
     * 
     * @param sysUserSalesExt 用户销售信息扩展
     * @return 用户销售信息扩展
     */
    @Override
    public List<SysUserSalesExt> selectSysUserSalesExtList(SysUserSalesExt sysUserSalesExt)
    {
        return sysUserSalesExtMapper.selectSysUserSalesExtList(sysUserSalesExt);
    }

    /**
     * 新增用户销售信息扩展
     * 
     * @param sysUserSalesExt 用户销售信息扩展
     * @return 结果
     */
    @Override
    public int insertSysUserSalesExt(SysUserSalesExt sysUserSalesExt)
    {
        return sysUserSalesExtMapper.insertSysUserSalesExt(sysUserSalesExt);
    }

    /**
     * 根据领导EmployeeId查询所有下属用户id
     *
     * @param bossEmployeeId 领导EmployeeId
     * @return 结果
     */
    @Override
    public List<String> selectEmployeeIdsByBossEmployeeId(String bossEmployeeId) {
        return sysUserSalesExtMapper.selectEmployeeIdsByBossEmployeeId(bossEmployeeId);
    }

    /**
     * 修改用户销售信息扩展
     * 
     * @param sysUserSalesExt 用户销售信息扩展
     * @return 结果
     */
    @Override
    public int updateSysUserSalesExt(SysUserSalesExt sysUserSalesExt)
    {
        return sysUserSalesExtMapper.updateSysUserSalesExt(sysUserSalesExt);
    }

    /**
     * 删除用户销售信息扩展对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteSysUserSalesExtByIds(String ids)
    {
        return sysUserSalesExtMapper.deleteSysUserSalesExtByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除用户销售信息扩展信息
     * 
     * @param userId 用户销售信息扩展ID
     * @return 结果
     */
    @Override
    public int deleteSysUserSalesExtById(Long userId)
    {
        return sysUserSalesExtMapper.deleteSysUserSalesExtById(userId);
    }
}
