package com.dgtly.wxportal.controller;

import com.alibaba.fastjson.JSONObject;
import com.dgtly.common.annotation.ApiPassToken;
import com.dgtly.common.core.controller.ApiBaseController;
import com.dgtly.common.core.domain.AjaxResult;
import com.dgtly.common.core.domain.ParameterObject;
import com.dgtly.wxportal.utils.qywxutils.QyWxSendMessageUtil;
import com.dgtly.wxportal.utils.qywxutils.QyWxUserUtil;
import com.dgtly.common.utils.RedisUtil;
import com.dgtly.system.domain.SysUser;
import com.dgtly.wxportal.domain.WxQyUser;
import com.dgtly.system.service.ISysUserService;
import com.dgtly.wxportal.service.IWxQyUserService;
import com.dgtly.wxportal.utils.qywxutils.messageModel.QyWxTextCard;
import com.dgtly.wxportal.utils.qywxutils.messageModel.QyWxTextCardMessage;
import com.dgtly.wxportal.utils.qywxutils.messageModel.QyWxTextMessage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;


@Api(tags = "企业微信相关API", description = "提供企业微信相关的AP")
@RequestMapping("wx")
@RestController
@ApiPassToken
public class WxController extends ApiBaseController {


    @Autowired
    private RedisUtil redisUtil;

    @Autowired
    private QyWxUserUtil qyWxUserUtil;

    @Autowired
    private IWxQyUserService wxQyUserService;
    @Autowired
    private ISysUserService sysUserService;

    @Autowired
    private QyWxSendMessageUtil qyWxSendMessageUtil;



    @ApiOperation(value = "获取微信授权跳转url",notes = "参数：{url:www.baidu.com}")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params" , paramType = "body")
    })
    @PostMapping("getOauthUrl")
    public Object getOauthUrl(){
        ParameterObject obj =  getParameterObject();
        obj.checkParameterNotNull("url");
        String oauth2Url =  qyWxUserUtil.getOauth2Url(obj.getString("url"),null);
        return AjaxResult.success().putKV("oauth2Url",oauth2Url);
    }

    @ApiOperation(value = "根据微信coed获取用户信息",
            notes = "参数：{code:123} code微信跳转回来的携带的用户code" +
                    "错误：301 当前用户不是当前企业用户成员" +
                    "错误：302 当前用户没有绑定")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params" , paramType = "body")
    })
    @PostMapping("getWxUserInfo")
    public Object getWxUserInfo(){
        ParameterObject obj =  getParameterObject();
        obj.checkParameterNotNull("code");
        String code = obj.getString("code");
        JSONObject json =  qyWxUserUtil.getUserId(code);
        String userId ="";
        if(!json.containsKey("UserId")){
            return AjaxResult.error(301,"当前用户不是企业成员");
        }
        userId = json.getString("UserId");
        WxQyUser wxQyUser = qyWxUserUtil.gerUserDetail(userId);
        WxQyUser resWxQyUser = wxQyUserService.selectWxQyUserById(wxQyUser.getUserid());
        if(resWxQyUser==null){
            int i = wxQyUserService.insertWxQyUser(wxQyUser);
            if(i>0){
                return AjaxResult.error(302,"当前用户没有绑定").putKV("wxUserInfo",wxQyUser);
            }else{
                return AjaxResult.error();
            }
        }

        if(resWxQyUser.getSysUserId()==null){
            return AjaxResult.error(302,"当前用户没有绑定").putKV("wxUserInfo",wxQyUser);
        }
        try{
            wxQyUser.setSysUserId(resWxQyUser.getSysUserId());

            wxQyUserService.updateWxQyUser(wxQyUser);
        }catch(Exception e){
            logger.error("更新微信用户信息时出错",e);
            e.printStackTrace();
        }
        SysUser user=sysUserService.selectUserById(resWxQyUser.getSysUserId());
        return AjaxResult.success().putKV("wxUser",resWxQyUser).putKV("sysUser",user);
    }



    @ApiOperation(value = "根据用户userId发送文本",
            notes = "参数：{userId:123," +
                    "content:\"XXXXXXXXXXXXXXXXXX\"} " +
                    "错误：301 当前用户未绑定企业微信")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params" , paramType = "body")
    })
    @PostMapping("sendTextMessage")
    public Object sendTextMessage(){
        ParameterObject obj =  getParameterObject();
        obj.checkParameterNotNull("userId,content");
        String userId = obj.getString("userId");
        WxQyUser wxQyUser = wxQyUserService.selectWxQyUserBySysUserId(userId);
        if(wxQyUser==null){
            logger.error("发送企业微信细信息对象为空");
            return AjaxResult.error(301,"发送对象位绑定企业微信");
        }
        QyWxTextMessage qyWxTextMessage = new QyWxTextMessage();
        qyWxTextMessage.setTouser(wxQyUser.getUserid());
        qyWxTextMessage.setText(obj.getString("content"));

        qyWxSendMessageUtil.sendMessage(qyWxTextMessage);
        return AjaxResult.success();
    }

    @ApiOperation(value = "根据用户userId发送文本card",
            notes = "参数：{userId:123," +
                    "title:\"标题，不超过128个字节\"," +
                    "description:\"描述，不超过512个字节\"" +
                    "url:\"点击后跳转的链接。\"," +
                    "btntxt:\"按钮文字。 默认为“详情”， 不超过4个文字\"} " +
                    "错误：301 当前用户未绑定企业微信")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params" , paramType = "body")
    })
    @PostMapping("sendTextCardMessage")
    public Object sendTextCardMessage(){
        ParameterObject obj =  getParameterObject();
        obj.checkParameterNotNull("userId,title,description,url");
        String userId = obj.getString("userId");

        QyWxTextCard tc = obj.parseBean(QyWxTextCard.class);

        WxQyUser wxQyUser = wxQyUserService.selectWxQyUserBySysUserId(userId);
        if(wxQyUser==null){
            logger.error("发送企业微信细信息对象为空");
            return AjaxResult.error(301,"发送对象位绑定企业微信");
        }
        QyWxTextCardMessage q = new QyWxTextCardMessage();

        q.setTouser(wxQyUser.getUserid());
        q.setTextcard(tc);
        qyWxSendMessageUtil.sendMessage(q);
        return AjaxResult.success();
    }




}
